@@ -4,6 +4,7 @@ import os
 import requests
 import subprocess
 import sys
+import time
 import argparse
 
 from conda_build.metadata import MetaData
@@ -11,6 +12,7 @@ from conda_build.metadata import MetaData
 from . import ci_register
 from . import configure_feedstock
 from . import lint_recipe
+from . import __version__
 
 
 PY2 = sys.version_info[0] == 2
@@ -43,7 +45,7 @@ def create_git_repo(target, msg):
         # prevent this:
         # bash: line 1: ./ci_support/run_docker_build.sh: Permission denied
         # ./ci_support/run_docker_build.sh returned exit code 126
-        subprocess.check_call(['git', 'update-index' '--chmod=+x' 'ci_support/run_docker_build.sh'], cwd=target)
+        subprocess.check_call(['git', 'update-index', '--chmod=+x', 'ci_support/run_docker_build.sh'], cwd=target)
     subprocess.check_call(['git', 'commit', '-m', msg], cwd=target)
 
 
@@ -105,7 +107,7 @@ class Init(Subcommand):
             print("\nRepository created, please edit conda-forge.yml to configure the upload channels\n"
                   "and afterwards call 'conda smithy register-github'")
         except RuntimeError as e:
-            print(e.message)
+            print(e)
 
 
 class RegisterGithub(Subcommand):
@@ -130,7 +132,7 @@ class RegisterGithub(Subcommand):
             github.create_github_repo(args)
             print("\nRepository registered at github, now call 'conda smithy register-ci'")
         except RuntimeError as e:
-            print(e.message)
+            print(e)
 
 
 class RegisterCI(Subcommand):
@@ -155,6 +157,8 @@ class RegisterCI(Subcommand):
         try:
             ci_register.add_project_to_travis(owner, repo)
             ci_register.travis_token_update_conda_forge_config(args.feedstock_directory, owner, repo)
+            time.sleep(1)
+            ci_register.travis_configure(owner, repo)
             ci_register.add_project_to_circle(owner, repo)
             ci_register.add_token_to_circle(owner, repo)
             ci_register.add_project_to_appveyor(owner, repo)
@@ -164,7 +168,7 @@ class RegisterCI(Subcommand):
             print("\nCI services have been enabled enabled. You may wish to regnerate the feedstock.\n"
                   "Any changes will need commiting to the repo.")
         except RuntimeError as e:
-            print(e.message)
+            print(e)
 
 class Regenerate(Subcommand):
     subcommand = 'regenerate'
@@ -181,7 +185,7 @@ class Regenerate(Subcommand):
             configure_feedstock.main(args.feedstock_directory)
             print("\nCI support files regenerated. These need to be pushed to github!")
         except RuntimeError as e:
-            print(e.message)
+            print(e)
 
 
 class RecipeLint(Subcommand):
@@ -220,6 +224,10 @@ def main():
             subcommand = 'rerender'
         Rerender(subparser)
 
+    parser.add_argument('--version', action='version',
+                        version=__version__,
+                        help="Show conda-smithy's version, and exit.")
+
     if not sys.argv[1:]:
         args = parser.parse_args(['--help'])
     else:
