@@ -4,6 +4,11 @@ import re
 import jinja2
 import ruamel.yaml
 
+# patch over differences between PY2 and PY3
+try:
+    text_type = unicode
+except NameError:
+    text_type = str
 
 EXPECTED_SECTION_ORDER = ['package', 'source', 'build', 'requirements',
                           'test', 'app', 'about', 'extra']
@@ -13,14 +18,15 @@ REQUIREMENTS_ORDER = ['build', 'run']
 
 class NullUndefined(jinja2.Undefined):
     def __unicode__(self):
-        return unicode(self._undefined_name)
+        return text_type(self._undefined_name)
 
     def __getattr__(self, name):
-        return unicode('{}.{}'.format(self, name))
+        return text_type('{}.{}'.format(self, name))
 
     def __getitem__(self, name):
         return '{}["{}"]'.format(self, name)
 
+
 def get_section(parent, name, lints):
     section = parent.get(name, {})
     if not isinstance(section, dict):
@@ -137,7 +143,7 @@ def main(recipe_dir):
     env = jinja2.Environment(undefined=NullUndefined)
 
     with open(recipe_meta, 'r') as fh:
-        content = env.from_string(''.join(fh)).render()
+        content = env.from_string(''.join(fh)).render(os=os)
         meta = ruamel.yaml.load(content, ruamel.yaml.RoundTripLoader)
     results = lintify(meta, recipe_dir)
     return results
